@@ -9,7 +9,7 @@ __PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
 
 use Business::UPS::Tracking::Utils;
 
-our $VERSION = $Business::UPS::Tracking::VERISON;
+our $VERSION = $Business::UPS::Tracking::VERSION;
 
 =encoding utf8
 
@@ -99,7 +99,7 @@ sub _build_address {
 
 =head1 METHODS
 
-=head2 serialize 
+=head2 printall 
 
 Serialize address into a string.
 
@@ -109,7 +109,7 @@ Moose meta method
 
 =cut
 
-sub serialize {
+sub printall {
     my ($self) = @_;
     
     my @address;
