@@ -3,6 +3,7 @@ package Business::UPS::Tracking::Response;
 # ============================================================================
 use utf8;
 use 5.0100;
+no if $] >= 5.017004, warnings => qw(experimental::smartmatch);
 
 use Moose;
 __PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
@@ -145,6 +146,8 @@ sub BUILD {
     }
 
     $self->shipment($shipment_return);
+    
+    return;
 }
 
 sub _build_CustomerContext {
