@@ -5,7 +5,6 @@ use utf8;
 use 5.0100;
 
 use Moose::Role;
-use strict; # Make cpants happy
 #requires('xml');
 
 use Business::UPS::Tracking::Element::Address;
@@ -13,6 +12,8 @@ use Business::UPS::Tracking::Element::Weight;
 use Business::UPS::Tracking::Element::ReferenceNumber;
 use Business::UPS::Tracking::Element::Code;
 
+our $VERSION = $Business::UPS::Tracking::VERSION;
+
 =encoding utf8
 
 =head1 NAME
@@ -116,4 +117,4 @@ sub build_referencenumber {
 }
 
 no Moose::Role;
-1;
\ No newline at end of file
+1;
